#!/bin/sh
echo 'name: statistics
version: 0.10.2.0
id: statistics-0.10.2.0-4eef500df4dc4035ce3725d46f9040fb

license: BSD3
copyright: 2009, 2010, 2011 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
stability:
homepage: https://github.com/bos/statistics
package-url:
synopsis: A library of statistical types, data, and functions
description: This library provides a number of common functions and types useful
             in statistics.  We focus on high performance, numerical robustness,
             and use of good algorithms.  Where possible, we provide
             references to the statistical literature.
             .
             The library'\''s facilities can be divided into four broad categories:
             .
             * Working with widely used discrete and continuous probability
             distributions.  (There are dozens of exotic distributions in use;
             we focus on the most common.)
             .
             * Computing with sample data: quantile estimation, kernel density
             estimation, histograms, bootstrap methods, significance testing,
             and autocorrelation analysis.
             .
             * Random variate generation under several different distributions.
             .
             * Common statistical tests for significant differences between
             samples.
             .
             Changes in 0.10.2.0
             .
             * Bugs in DCT and IDCT are fixed.
             .
             * Accesors for uniform distribution are added.
             .
             * '\''ContGen'\'' instances for all continous distribtuions are added.
             .
             * Beta distribution is added.
             .
             * Constructor for improper gamma distribtuion is added.
             .
             * Binomial distribution allows zero trials.
             .
             * Poisson distribution now accept zero parameter.
             .
             * Integer overflow in caculation of Wilcoxon-T test is fixed.
             .
             * Bug in '\''ContGen'\'' instance for normal distribution is fixed.
             .
             Changes in 0.10.1.0
             .
             * Kolmogorov-Smirnov nonparametric test added.
             .
             * Pearson'\''s chi squared test added.
             .
             * Type class for generating random variates for given distribution
             is added.
             .
             * Modules '\''Statistics.Math'\'' and '\''Statistics.Constants'\'' are moved to
             the @math-functions@ package. They are still available but marked
             as deprecated.
             .
             Changed in 0.10.0.1
             .
             * @dct@ and @idct@ now have type @Vector Double -> Vector Double@
             .
             Changes in 0.10.0.0:
             .
             * The type classes @Mean@ and @Variance@ are split in two. This is
             required for distributions which do not have finite variance or
             mean.
             .
             * The @S.Sample.KernelDensity@ module has been renamed, and
             completely rewritten to be much more robust.  The older module
             oversmoothed multi-modal data.  (The older module is still
             available under the name @S.Sample.KernelDensity.Simple@).
             .
             * Histogram computation is added, in @S.Sample.Histogram@.
             .
             * Forward and inverse discrete Fourier and cosine transforms are
             added, in @S.Transform@.
             .
             * Root finding is added, in @S.Math.RootFinding@.
             .
             * The @complCumulative@ function is added to the @Distribution@
             class in order to accurately assess probalities P(X>x) which are
             used in one-tailed tests.
             .
             * A @stdDev@ function is added to the @Variance@ class for
             distributions.
             .
             * The constructor @S.Distribution.normalDistr@ now takes standard
             deviation instead of variance as its parameter.
             .
             * A bug in @S.Quantile.weightedAvg@ is fixed. It produced a wrong
             answer if a sample contained only one element.
             .
             * Bugs in quantile estimations for chi-square and gamma distribution
             are fixed.
             .
             * Integer overlow in @mannWhitneyUCriticalValue@ is fixed. It
             produced incorrect critical values for moderately large
             samples. Something around 20 for 32-bit machines and 40 for 64-bit
             ones.
             .
             * A bug in @mannWhitneyUSignificant@ is fixed. If either sample was
             larger than 20, it produced a completely incorrect answer.
             .
             * One- and two-tailed tests in @S.Tests.NonParametric@ are selected
             with sum types instead of @Bool@.
             .
             * Test results returned as enumeration instead of @Bool@.
             .
             * Performance improvements for Mann-Whitney U and Wilcoxon tests.
             .
             * Module @S.Tests.NonParamtric@ is split into @S.Tests.MannWhitneyU@
             and @S.Tests.WilcoxonT@
             .
             * @sortBy@ is added to @S.Function@.
             .
             * Mean and variance for gamma distribution are fixed.
             .
             * Much faster cumulative probablity functions for Poisson and
             hypergeometric distributions.
             .
             * Better density functions for gamma and Poisson distributions.
             .
             * Student-T, Fisher-Snedecor F-distributions and Cauchy-Lorentz
             distrbution are added.
             .
             * The function @S.Function.create@ is removed. Use @generateM@ from
             the @vector@ package instead.
             .
             * Function to perform approximate comparion of doubles is added to
             @S.Function.Comparison@
             .
             * Regularized incomplete beta function and its inverse are added to
             @S.Function@.
category: Math, Statistics
author: Bryan O'\''Sullivan <bos@serpentine.com>
exposed: True
exposed-modules: Statistics.Autocorrelation Statistics.Constants
                 Statistics.Distribution Statistics.Distribution.Beta
                 Statistics.Distribution.Binomial
                 Statistics.Distribution.CauchyLorentz
                 Statistics.Distribution.ChiSquared
                 Statistics.Distribution.Exponential
                 Statistics.Distribution.FDistribution Statistics.Distribution.Gamma
                 Statistics.Distribution.Geometric
                 Statistics.Distribution.Hypergeometric
                 Statistics.Distribution.Normal Statistics.Distribution.Poisson
                 Statistics.Distribution.StudentT Statistics.Distribution.Uniform
                 Statistics.Function Statistics.Math Statistics.Math.RootFinding
                 Statistics.Quantile Statistics.Resampling
                 Statistics.Resampling.Bootstrap Statistics.Sample
                 Statistics.Sample.Histogram Statistics.Sample.KernelDensity
                 Statistics.Sample.KernelDensity.Simple Statistics.Sample.Powers
                 Statistics.Test.NonParametric Statistics.Test.ChiSquared
                 Statistics.Test.KolmogorovSmirnov Statistics.Test.MannWhitneyU
                 Statistics.Test.WilcoxonT Statistics.Test.Types
                 Statistics.Transform Statistics.Types
hidden-modules: Statistics.Distribution.Poisson.Internal
                Statistics.Function.Comparison Statistics.Internal
                Statistics.Test.Internal
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/statistics-0.10.2.0
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/statistics-0.10.2.0
              /usr/local/lib
hs-libraries: HSstatistics-0.10.2.0
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         deepseq-1.3.0.0-c26e15897417ecd448742528253d68f6
         erf-2.0.0.0-28be20c62c471901eba440fcdaa562f5
         math-functions-0.1.3.0-add2ab0530e447f63182d443375d8e1d
         monad-par-0.3.4.1-19a71476bd1f87f8fbc85fd4ebfaca0b
         mwc-random-0.12.0.1-6150181fa129b5a3adc2cb4de368f6b4
         primitive-0.5.0.1-15cdc8c11a54a78809b647af0c2975b3
         vector-0.10.0.1-3450daae3d9f2092020075d05481123c
         vector-algorithms-0.5.4.2-a0be95fd4d71e8d525b9ea777d300462
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/statistics-0.10.2.0/html/statistics.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/statistics-0.10.2.0/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
